@@ -10,6 +10,7 @@ use Doctrine\DBAL\Platforms\SQLitePlatform;
 use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\ColumnDiff;
 use Doctrine\DBAL\Schema\ForeignKeyConstraint;
+use Doctrine\DBAL\Schema\SQLiteSchemaManager;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Schema\TableDiff;
 use Doctrine\DBAL\Types\BlobType;
@@ -17,7 +18,9 @@ use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
 
 use function array_keys;
+use function array_map;
 use function array_shift;
+use function assert;
 
 class SQLiteSchemaManagerTest extends SchemaManagerFunctionalTestCase
 {
@@ -393,6 +396,81 @@ SQL;
         );
     }
 
+    public function testListTableNoSchemaEmulation(): void
+    {
+        $databasePlatform = $this->connection->getDatabasePlatform();
+        assert($databasePlatform instanceof SQLitePlatform);
+
+        $this->dropTableIfExists('`list_table_no_schema_emulation.test`');
+
+        $this->connection->executeStatement(<<<'DDL'
+            CREATE TABLE `list_table_no_schema_emulation.test` (
+                id INTEGER,
+                parent_id INTEGER,
+                PRIMARY KEY (id),
+                FOREIGN KEY (parent_id) REFERENCES `list_table_no_schema_emulation.test` (id)
+            );
+            DDL);
+
+        $this->connection->executeStatement(<<<'DDL'
+            CREATE INDEX i ON `list_table_no_schema_emulation.test` (parent_id);
+            DDL);
+
+        $customSQLiteSchemaManager = new class ($this->connection, $databasePlatform) extends SQLiteSchemaManager {
+            /** @return list<array<string, mixed>> */
+            public function selectTableColumnsWithSchema(): array
+            {
+                return $this->selectTableColumns('main', 'list_table_no_schema_emulation.test')
+                    ->fetchAllAssociative();
+            }
+
+            /** @return list<array<string, mixed>> */
+            public function selectIndexColumnsWithSchema(): array
+            {
+                return $this->selectIndexColumns('main', 'list_table_no_schema_emulation.test')
+                    ->fetchAllAssociative();
+            }
+
+            /** @return list<array<string, mixed>> */
+            public function selectForeignKeyColumnsWithSchema(): array
+            {
+                return $this->selectForeignKeyColumns('main', 'list_table_no_schema_emulation.test')
+                    ->fetchAllAssociative();
+            }
+        };
+
+        self::assertSame(
+            [
+                ['list_table_no_schema_emulation.test', 'id'],
+                ['list_table_no_schema_emulation.test', 'parent_id'],
+            ],
+            array_map(
+                static fn (array $row) => [$row['table_name'], $row['name']],
+                $customSQLiteSchemaManager->selectTableColumnsWithSchema(),
+            ),
+        );
+
+        self::assertSame(
+            [
+                ['list_table_no_schema_emulation.test', 'i'],
+            ],
+            array_map(
+                static fn (array $row) => [$row['table_name'], $row['name']],
+                $customSQLiteSchemaManager->selectIndexColumnsWithSchema(),
+            ),
+        );
+
+        self::assertSame(
+            [
+                ['list_table_no_schema_emulation.test', 'parent_id', 'id'],
+            ],
+            array_map(
+                static fn (array $row) => [$row['table_name'], $row['from'], $row['to']],
+                $customSQLiteSchemaManager->selectForeignKeyColumnsWithSchema(),
+            ),
+        );
+    }
+
     /**
      * This test duplicates {@see parent::testCommentInTable()} with the only difference that the name of the table
      * being created is quoted. It is only meant to cover the logic of parsing the SQLite CREATE TABLE statement
